@@ -12,8 +12,7 @@
 
 REDIRECT=/dev/null
 
-if [ -f ${data_dir}/geavg.t12z.pgrbaf108 ]
-then
+if [ -f ${data_dir}/geavg.t12z.pgrbaf108 ]; then
    tmpdata=grib_api.$$.grib
    rm -f $tmpdata
    ${tools_dir}/grib_filter ${data_dir}/filter_rules ${data_dir}/geavg.t12z.pgrbaf108 > $REDIRECT
@@ -21,7 +20,7 @@ then
 fi
 
 cat >${data_dir}/f.rules <<EOF
-write "${data_dir}/split/[centre]_[date]_[dataType]_[gridType]_[levelType]_[level]_[short_name]_[packingType].grib[editionNumber]";
+ write "${data_dir}/split/[centre]_[date]_[dataType]_[gridType]_[levelType]_[level]_[short_name]_[packingType].grib[editionNumber]";
 EOF
 
 [ -d ${data_dir}/split ] || mkdir -p ${data_dir}/split 
@@ -35,7 +34,7 @@ rm -f ${data_dir}/f.rules
 echo "Test with nonexistent keys. Note spelling of centre!"
 # ---------------------------------------------------------
 cat >${data_dir}/nonexkey.rules <<EOF
-set center="john";
+ set center="john";
 EOF
 # Invoke without -f i.e. should fail if error encountered
 set +e
@@ -53,8 +52,8 @@ rm -f ${data_dir}/nonexkey.rules
 echo "Test GRIB-308: format specifier for integer keys"
 # ----------------------------------------------------
 cat > ${data_dir}/formatint.rules <<EOF
-# Pad edition with leading zeroes and level with blanks
-print "edition=[edition%.3d], level=[level%5ld]";
+ # Pad edition with leading zeroes and level with blanks
+ print "edition=[edition%.3d], level=[level%5ld]";
 EOF
 
 result=`${tools_dir}/grib_filter  ${data_dir}/formatint.rules  $ECCODES_SAMPLES_PATH/GRIB1.tmpl`
@@ -63,14 +62,14 @@ result=`${tools_dir}/grib_filter  ${data_dir}/formatint.rules  $ECCODES_SAMPLES_
 echo "Test ECC-636: print all array entries on one line, num columns=0"
 # --------------------------------------------------------------------
 cat > ${data_dir}/formatint.rules <<EOF
-print "[values\!0]";
+ print "[values\!0]";
 EOF
 numlines=`${tools_dir}/grib_filter  ${data_dir}/formatint.rules  $ECCODES_SAMPLES_PATH/GRIB1.tmpl | wc -l | tr -d ' '`
 [ "$numlines" = "1" ]
 
 # If there is an error in the num columns, use 8
 cat > ${data_dir}/formatint.rules <<EOF
-print "[values\!XXX]";
+ print "[values\!XXX]";
 EOF
 numlines=`${tools_dir}/grib_filter  ${data_dir}/formatint.rules  $ECCODES_SAMPLES_PATH/GRIB1.tmpl | wc -l | tr -d ' '`
 [ "$numlines" = "8146" ]
@@ -78,10 +77,10 @@ numlines=`${tools_dir}/grib_filter  ${data_dir}/formatint.rules  $ECCODES_SAMPLE
 echo "Test conversion from grib1 to grib2 'Generalized vertical height coordinates'"
 # --------------------------------------------------------------------------------
 cat >temp.filt <<EOF
-set edition=2;
-set typeOfLevel="generalVertical";
-set nlev=41.0;
-write;
+ set edition=2;
+ set typeOfLevel="generalVertical";
+ set nlev=41.0;
+ write;
 EOF
 
 ${tools_dir}/grib_filter -o temp_filt.grib2 temp.filt $ECCODES_SAMPLES_PATH/sh_ml_grib1.tmpl
@@ -91,30 +90,30 @@ result=`${tools_dir}/grib_get -p typeOfFirstFixedSurface,NV,nlev temp_filt.grib2
 echo "Test GRIB-394: grib_filter arithmetic operators not correct for floating point values"
 # -----------------------------------------------------------------------------------------
 cat > ${data_dir}/binop.rules <<EOF
-transient val_exact=209.53530883789062500000;
-if (referenceValue == val_exact) {
+ transient val_exact=209.53530883789062500000;
+ if (referenceValue == val_exact) {
    print "OK Equality test passed";
-}
-else {
+ }
+ else {
    print "***ERROR: float equality test";
    assert(0);
-}
-transient val_lower=209;
-if (referenceValue > val_lower) {
-  print "OK [referenceValue] > [val_lower]";
-}
-else {
-  print "***ERROR: [referenceValue] <= [val_lower]";
-  assert(0);
-}
-transient val_higher=209.99;
-if (referenceValue < val_higher) {
-  print "OK [referenceValue] < [val_higher]";
-}
-else {
-  print "***ERROR: [referenceValue] >= [val_higher]";
-  assert(0);
-}
+ }
+ transient val_lower=209;
+ if (referenceValue > val_lower) {
+   print "OK [referenceValue] > [val_lower]";
+ }
+ else {
+   print "***ERROR: [referenceValue] <= [val_lower]";
+   assert(0);
+ }
+ transient val_higher=209.99;
+ if (referenceValue < val_higher) {
+   print "OK [referenceValue] < [val_higher]";
+ }
+ else {
+   print "***ERROR: [referenceValue] >= [val_higher]";
+   assert(0);
+ }
 EOF
 ${tools_dir}/grib_filter  ${data_dir}/binop.rules $ECCODES_SAMPLES_PATH/gg_sfc_grib1.tmpl >/dev/null
 
@@ -122,13 +121,13 @@ ${tools_dir}/grib_filter  ${data_dir}/binop.rules $ECCODES_SAMPLES_PATH/gg_sfc_g
 echo "Test GRIB-526: grib_filter very picky about format of floats"
 # ----------------------------------------------------------------
 cat >temp.filt <<EOF
-set values = {
-  -1000.0,
-  3.1e5,
-  66,
-  -77,
-  .4,
-  45. };
+ set values = {
+   -1000.0,
+   3.1e5,
+   66,
+   -77,
+   .4,
+   45. };
 EOF
 ${tools_dir}/grib_filter temp.filt $ECCODES_SAMPLES_PATH/GRIB1.tmpl
 
@@ -161,10 +160,10 @@ rm -f temp.out.gfilter.*.grib
 echo "Test ECC-648: Set codetable key to array"
 # ---------------------------------------------
 cat >temp.filt <<EOF
-  set productDefinitionTemplateNumber = 11;
-  set numberOfTimeRange = 3;
-  set typeOfStatisticalProcessing = {3, 1, 2};
-  write;
+ set productDefinitionTemplateNumber = 11;
+ set numberOfTimeRange = 3;
+ set typeOfStatisticalProcessing = {3, 1, 2};
+ write;
 EOF
 ${tools_dir}/grib_filter -o temp_filt.grib2 temp.filt $ECCODES_SAMPLES_PATH/GRIB2.tmpl
 stats=`echo 'print "[typeOfStatisticalProcessing]";' | ${tools_dir}/grib_filter - temp_filt.grib2`
@@ -184,6 +183,13 @@ count=`${tools_dir}/grib_count temp_filt.grib2`
 [ $count -eq 76 ]
 
 
+echo "Test ECC-1233"
+# ------------------
+sample1=$ECCODES_SAMPLES_PATH/sh_ml_grib1.tmpl
+padding=`echo 'print "[padding_grid50_1]";' | ${tools_dir}/grib_filter - $sample1`
+[ "$padding" = "000000000000000000000000000000000000" ]
+
+
 # Clean up
 rm -f temp_filt.grib2 temp.filt
 rm -f ${data_dir}/formatint.rules ${data_dir}/binop.rules
